@@ -85,7 +85,7 @@ int STRING_CONVERT_TO_INTEGER(char *str, int *number)
 void STRING_PRINT(const char str[])
 {
 	if (!(opt_quiet)){
-		fprintf(stdout, str);
+		fprintf(stdout, "%s", str);
 		fflush(stdout);
 	}
 }
@@ -100,7 +100,7 @@ void STRING_PRINT(const char str[])
 void STRING_PRINTE(const char str[])
 {
 //	if (!(opt_quiet)){
-		fprintf(stderr, str);
+		fprintf(stderr, "%s", str);
 		fflush(stderr);
 //	}
 }
@@ -121,7 +121,7 @@ void STRING_PRINTV(const char str[])
 		int t = time(NULL) - mytime;
 		if (t > 1){ printf("(%d) ", t-1); }
 		// print text
-		fprintf(stdout, str);
+		fprintf(stdout, "%s", str);
 		fflush(stdout);
 	}
     }
@@ -132,7 +132,7 @@ void STRING_PRINTV2(const char str[])
     if(opt_verbose){
 	if (!(opt_quiet)){
 		// print text
-		fprintf(stdout, str);
+		fprintf(stdout, "%s", str);
 		fflush(stdout);
 	}
     }
@@ -237,7 +237,7 @@ void GET_FILE_NAME(char *strin, char *strout)
 	// check only path
 	c = 0;
 	i = len-1;
-	while ((i >= 0) && (strin[i] != slsh[0])) { c++; i--; }
+	while ((i >= 0) && (strin[i] != slsh)) { c++; i--; }
 	//if (i >= 0) {
 		for (i=0; i<c; i++) {
 			if (i < max_char) {
@@ -263,7 +263,7 @@ void GET_FILE_NAME_ONLY(char *strin, char *strout)
 	len = i;
 	// check only path
 	i = len-1;
-	while ((i >= 0) && (strin[i] != slsh[0])) { i--; }
+	while ((i >= 0) && (strin[i] != slsh)) { i--; }
     st = i + 1;
 	// check extension of file
 	c = 0;
@@ -329,7 +329,7 @@ void GET_FILE_PATH(char *strin, char *strout)
 	// check only path
 	c = 0;
 	i = len-1;
-	while ((i >= 0) && (strin[i] != slsh[0])) { c++; i--; }
+	while ((i >= 0) && (strin[i] != slsh)) { c++; i--; }
 	if (i >= 0) {
 		for (i=0; i<len-c; i++) {
 			if (i < max_char-1) {
@@ -540,10 +540,10 @@ int FILE_LIST_ADD(char *file_name)
 		// remove '/' characters from the end of directory names if more than 1
                 int flag = 0;
                 while ((i > 1) && (flag == 0)) {
-                    if (file_name_new[i-1] == slsh[0]) { i--; }
+                    if (file_name_new[i-1] == slsh) { i--; }
                     else { flag = 1; } }
 		// add '/' character to directory path
-                file_name_new[i] = slsh[0];
+                file_name_new[i] = slsh;
 
 		// add found file name to directory path
                 i++;
@@ -672,7 +672,7 @@ int EXIF_GET(char *file_name)
         return 1;
     }
 
-    // seek for beginning of exif info (start ofset = 2)
+    // seek for beginning of exif info (start offset = 2)
     exif_start = 2;
     int exif_ok = 0;
     int exif_bad = 0;
@@ -895,7 +895,7 @@ int BITMAP_READ_BMP(char *file_name)
         bitmap_format_bmp_clrspc_type = f_bitcount;
 
         if (f_bitcount == 8){
-		// ofset pointing to color palette
+		// offset pointing to color palette
 	    	f_headersize = 14;
 	    	f_headersize += file_buffer[14] << 0;
 	    	f_headersize += file_buffer[15] << 8;
@@ -904,7 +904,10 @@ int BITMAP_READ_BMP(char *file_name)
 		// check whether the 8 bit image contains only gray colors?
 		int gray_flag;
 		gray_flag = 1;
+
+		#ifdef __OPENMP__
 		#pragma omp parallel for num_threads(max_threads)
+		#endif
 		for (i=0; i<256; i++){
 			if ((file_buffer[i*4+f_headersize+0] != file_buffer[i*4+f_headersize+1]) ||
 				(file_buffer[i*4+f_headersize+1] != file_buffer[i*4+f_headersize+2])){ gray_flag = 0; }
@@ -915,7 +918,7 @@ int BITMAP_READ_BMP(char *file_name)
 			free(file_buffer); return 1; }
 		}
 
-		// ofset pointing to RGB datas
+		// offset pointing to RGB datas
 		f_offs = 0;
 		f_offs += file_buffer[10] << 0;
 		f_offs += file_buffer[11] << 8;
@@ -976,7 +979,9 @@ int BITMAP_READ_BMP(char *file_name)
             if (f_bitcount == 8){
        		addr_offset = f_width % 4;
                	if (addr_offset != 0) addr_offset = 4 - addr_offset;
+		#ifdef __OPENMP__
 		#pragma omp parallel for private(x, y, addr, addr2) num_threads(max_threads)
+		#endif
     	    	for (y=0; y<=bh-1; y++){
     	    		addr2 = y * bw * 1 + y * addr_offset;
     	    		for (x=0; x<=bw-1; x++){
@@ -990,7 +995,9 @@ int BITMAP_READ_BMP(char *file_name)
             else{
        		addr_offset = (f_width) * 3 % 4;
                	if (addr_offset != 0) addr_offset = 4 - addr_offset;
+		#ifdef __OPENMP__
 		#pragma omp parallel for private(x, y, addr, addr2) num_threads(max_threads)
+		#endif
     	    	for (y=0; y<=bh-1; y++){
     	    		addr2 = y * bw * 3 + y * addr_offset;
     	    		for (x=0; x<=bw-1; x++){
@@ -1074,7 +1081,7 @@ int BITMAP_WRITE_BMP(char *file_name)
 	file_buffer[9] = 0;
 
     if (bitmap_format_bmp_clrspc_type == 8) {
-    	// bitmap ofset (standard = 54)
+    	// bitmap offset (standard = 54)
     	file_buffer[10] = 54;
     	file_buffer[11] = 4; // + 4 * 256 pcs of RGB gray colors = $0400 pcs
     	file_buffer[12] = 0;
@@ -1084,7 +1091,7 @@ int BITMAP_WRITE_BMP(char *file_name)
     	file_buffer[29] = 0;
     }
     else {
-    	// bitmap ofset (standard = 54)
+    	// bitmap offset (standard = 54)
     	file_buffer[10] = 54;
 	file_buffer[11] = 0;
 	file_buffer[12] = 0;
@@ -1139,7 +1146,9 @@ int BITMAP_WRITE_BMP(char *file_name)
 
 	/* print info */ STRING_PRINTV("copying colors from bitmap buffer to bmp object\n");
     if (bitmap_format_bmp_clrspc_type == 8) {
+	#ifdef __OPENMP__
 	#pragma omp parallel for num_threads(max_threads)
+	#endif
 	for (i=0; i<256; i++){
             file_buffer[54 + i*4 + 0] = i;
             file_buffer[54 + i*4 + 1] = i;
@@ -1149,7 +1158,9 @@ int BITMAP_WRITE_BMP(char *file_name)
 
     	f_offs = 54 + 4 * 256;
     	addr = 0;
+	#ifdef __OPENMP__
 	#pragma omp parallel for private(x, y, addr, addr2, col) num_threads(max_threads)
+	#endif
     	for (y=0; y<=bh-1; y++){
     		addr2 = y * (bw + addr_offset);
     		for (x=0; x<=bw-1; x++){
@@ -1164,7 +1175,9 @@ int BITMAP_WRITE_BMP(char *file_name)
     else {
     	f_offs = 54;
     	addr = 0;
+	#ifdef __OPENMP__
 	#pragma omp parallel for private(x, y, addr, addr2) num_threads(max_threads)
+	#endif
     	for (y=0; y<=bh-1; y++){
     		addr2 = y * (bw * 3 + addr_offset);
     		for (x=0; x<=bw-1; x++){
@@ -1271,7 +1284,9 @@ int BITMAP_READ_JASPER(char *file_name)
 		jas_image_readcmpt(image, channel, 0, 0, dx, dy, data);
 		jas_image_setcmpttype(image, channel, JAS_IMAGE_CT_RGB_R+channel);
 
+		#ifdef __OPENMP__
 		#pragma omp parallel for private(i, j) num_threads(max_threads)
+		#endif
 	    	for (j=0; j<dy; j++){
 	    		for (i=0; i<dx; i++){
 	    			int idx=(j * dx + i) * 3;
@@ -1341,7 +1356,9 @@ int BITMAP_WRITE_JASPER(char *file_name)
 	long channel;
 	long idx;
 	for (channel=0; channel<3; channel++){
+		#ifdef __OPENMP__
 		#pragma omp parallel for private(i, j, idx) num_threads(max_threads)
+		#endif
 		for (j=0; j<dy; j++){
 			for (i=0; i<dx; i++){
 				idx=(j * dx + i) * 3;
@@ -1429,7 +1446,7 @@ int BITMAP_READ_PNG(char *file_name)
 
 	// check PNG signature
 	unsigned char sig[8];
-	fread(sig, 1, 8, fhandle);
+	if (fread(sig, 1, 8, fhandle) != 8) return 1;
 
 //	libpng version change to 1.4.0
 //	if (!png_check_sig(sig, 8)) return 1;
@@ -1525,6 +1542,9 @@ int BITMAP_READ_PNG(char *file_name)
         if (bitmap_format_png_clrspc_type == 4) { alpha_flag = 1; }
         if (bitmap_format_png_clrspc_type == 6) { alpha_flag = 2; }
 
+	if (alpha_flag){ /* print info */ STRING_PRINTV("alpha channel exists\n"); }
+	else           { /* print info */ STRING_PRINTV("no alpha channel\n");     }
+
 	/* print info */ STRING_PRINTV("allocating memory for uncompressed bitmap image\n");
 	bitmap_buffer = malloc(bitmap_width * bitmap_height * (3 + alpha_flag));
 	if (bitmap_buffer == 0) {
@@ -1542,7 +1562,9 @@ int BITMAP_READ_PNG(char *file_name)
 
 
 	/* print info */ STRING_PRINTV("creating row pointers for bitmap buffer\n");
+	#ifdef __OPENMP__
 	#pragma omp parallel for num_threads(max_threads)
+	#endif
 	for (i = 0;  i < bitmap_height;  ++i)
 		row_pointers[i] = bitmap_buffer + i*rowbytes;
 
@@ -1816,7 +1838,9 @@ int BITMAP_WRITE_PNG(char *file_name)
 
 
 	/* print info */ STRING_PRINTV("creating row pointers for bitmap buffer\n");
+	#ifdef __OPENMP__
 	#pragma omp parallel for num_threads(max_threads)
+	#endif
         for (i = 0;  i < bitmap_height;  ++i)
                 row_pointers[i] = bitmap_buffer + i*rowbytes;
 
@@ -1831,7 +1855,6 @@ int BITMAP_WRITE_PNG(char *file_name)
 	return 0;
 }
 
-#endif
 
 
 
@@ -1904,7 +1927,9 @@ int BITMAP_READ_JPEG(char *file_name)
 
 		int i;
 		if (cinfo.output_components == 3){
+			#ifdef __OPENMP__
 			#pragma omp parallel for num_threads(max_threads)
+			#endif
 			for (i=0; i<cinfo.output_width; i++){
 				bitmap_buffer[0 + i*3 + (cinfo.output_scanline-1) * cinfo.output_width*3] = *(*buffer + 0 + i*3);
 				bitmap_buffer[1 + i*3 + (cinfo.output_scanline-1) * cinfo.output_width*3] = *(*buffer + 1 + i*3);
@@ -1912,7 +1937,9 @@ int BITMAP_READ_JPEG(char *file_name)
 			}
 		}
 		else{
+			#ifdef __OPENMP__
 			#pragma omp parallel for num_threads(max_threads)
+			#endif
 			for (i=0; i<cinfo.output_width; i++){
 				bitmap_buffer[0 + i*3 + (cinfo.output_scanline-1) * cinfo.output_width*3] = *(*buffer + 0 + i);
 				bitmap_buffer[1 + i*3 + (cinfo.output_scanline-1) * cinfo.output_width*3] = *(*buffer + 0 + i);
@@ -2045,6 +2072,7 @@ int BITMAP_WRITE_JPEG(char *file_name)
 	return 0;
 }
 
+#endif
 
 
 
