@@ -16,9 +16,6 @@
 ------------------------------------------------------------------------*/
 
 
-//#define __UNIX__
-//#define __WIN32__
-//#define __AROS__
 //#define __BMP_ONLY__
 
 
@@ -32,6 +29,10 @@
 /*
 aaphoto Changelog:
 --------------------
+2010/07/18 - aaphoto v0.38 - additional verbose message showing presence of alpha channel in PNG images
+                           - bugfix: fix compile with only BMP support
+                           - fix some warning messages during build
+                           - removing unnecessary __WIN32__ macro
 2010/05/10 - aaphoto v0.37 - OpenMP support added for multi processing, all possible time intensive codes paralleled
                              __OPENMP__ directive and -fopenmp option are needed at compile time (supported since GCC v4.2)
                              (not available on windows platform yet)
@@ -212,12 +213,8 @@ int opt_openmp;
 #endif
 
 
-// system dependent file name separation character
-#ifdef __WIN32__
-	char slsh[] = "\\";
-#else
-	char slsh[] = "/";
-#endif
+// file name separation character
+char slsh='/';
 
 
 #ifndef __BMP_ONLY__
@@ -246,9 +243,9 @@ char *helpinfo[] = {
 "Copyright (C) 2006-2010 Andras Horvath\n"
 "E-mail: mail@log69.com - suggestions & feedbacks are welcome\n"
 "URL: http://log69.com - the official site\n"
-"aaphoto (command-line) version - v0.37\n"
+"aaphoto (command-line) version - v0.38\n"
 "aaRGB (color-correction engine) version - v0.61\n"
-"last update = 10/05/2010\n"
+"last update = 18/07/2010\n"
 "\n"
 #ifndef __BMP_ONLY__
 "The following libraries are used by this program:\n"
@@ -321,7 +318,7 @@ char *helpinfo[] = {
 "         --jp2           JPEG 2000 image output\n"
 "         --png           PNG image output with alpha channel support\n"
 "         --bmp           BMP image output\n"
-"    -r   --resize        Resize image taking the longer side in %% or pixels\n"
+"    -r   --resize        Resize image taking the longer side in % or pixels\n"
 "         --rotate90      Rotate image with 90 degrees clockwise\n"
 "         --rotate180     Rotate image with 180 degrees\n"
 "         --rotate270     Rotate image with 90 degrees counter-clockwise\n"
@@ -340,7 +337,7 @@ char *helpinfo[] = {
 "     aaphoto image.jpg\n"
 "     aaphoto -a -r600 -q85 *.jpg\n"
 "     aaphoto mydir\n"
-"     aaphoto -V --resize70%% image.png\n"
+"     aaphoto -V --resize70% image.png\n"
 "     aaphoto --quality60 image.jp2\n"
 "\n"
 "REMARKS:\n"
@@ -351,7 +348,7 @@ char *helpinfo[] = {
 "- resizing can be set in percentage too\n"
 "- resize parameter should be less or equal than original\n"
 "- resize uses the best (and slowest) resampling method\n"
-"- default jpeg compression quality is 95%%\n"
+"- default jpeg compression quality is 95%\n"
 "- EXIF information is restored in jpeg images by default\n"
 "\n\0"
 
@@ -618,8 +615,8 @@ int MAIN_ARGUMENTS_READ(int argc, char **argv)
 					}
 					// check if output path ends with slash character
 					// if not, then append it
-					if (output_ending != slsh[0]){
-						opt_output_path [i] = slsh[0];
+					if (output_ending != slsh){
+						opt_output_path [i] = slsh;
 						i++;
 					}
 					opt_output_path [i] = 0;
@@ -658,8 +655,8 @@ int MAIN_ARGUMENTS_READ(int argc, char **argv)
 						}
 						// check if output path ends with slash character
 						// if not, then append it
-						if (output_ending != slsh[0]){
-							opt_output_path [i] = slsh[0];
+						if (output_ending != slsh){
+							opt_output_path [i] = slsh;
 							i++;
 						}
 						opt_output_path [i] = 0;
