@@ -421,7 +421,9 @@ void AARGB_MAIN(
 // színskálájáról a képnek
 
     // array initialization with zeros
+    #ifdef __OPENMP__
     #pragma omp parallel for num_threads(max_threads)
+    #endif
     for (i1=0; i1<256; i1++){
         hist1[i1] = 0;
         hist2[i1] = 0;
@@ -442,7 +444,9 @@ void AARGB_MAIN(
 	}
     }
 
+    #ifdef __OPENMP__
     #pragma omp parallel for private(x, y, addr, addr2, col_r, col_g, col_b, cc) num_threads(max_threads)
+    #endif
     for (y=0; y<=bh-1; y++){
         addr2 = y * bw * 3 + y * addr_offset;
         for (x=0; x<=bw-1; x++){
@@ -473,7 +477,9 @@ void AARGB_MAIN(
     }
 
     // this is a replacement code for arrays for multi processing
+    #ifdef __OPENMP__
     #pragma omp parallel for num_threads(max_threads)
+    #endif
     for (i1=0; i1<256; i1++){
 	for (i2=0; i2<max_threads; i2++){
 		hist1[i1]  += hist1n[i1][i2];
@@ -597,7 +603,9 @@ void AARGB_MAIN(
 
     i3 = 0;
     // fekete pont alatti összes szín RGB átlagának kiszámítása
+    #ifdef __OPENMP__
     #pragma omp parallel for reduction(+:bp_r, bp_g, bp_b, i3) num_threads(max_threads)
+    #endif
     for (i1=(long)(bp * 255); i1>=0; i1--){
         bp_r += col_r3[i1];
         bp_g += col_g3[i1];
@@ -612,7 +620,9 @@ void AARGB_MAIN(
 
     i3 = 0;
     // fehér pont feletti összes szín RGB átlagának kiszámítása
+    #ifdef __OPENMP__
     #pragma omp parallel for reduction(+:wp_r, wp_g, wp_b, i3) num_threads(max_threads)
+    #endif
     for (i1=(long)(wp * 255); i1<256; i1++){
         wp_r += col_r3[i1];
         wp_g += col_g3[i1];
@@ -787,7 +797,9 @@ printf("\nwp_r_end = %f, wp_g_end = %f, wp_b_end = %f\n", wp_r_end, wp_g_end, wp
 
 // Ez a hisztogram lesz felhasználva a gamma súlypont megállapításához
 
+    #ifdef __OPENMP__
     #pragma omp parallel for private(temp2, temp3, cc) num_threads(max_threads)
+    #endif
     for (i1=0; i1<256; i1++){
 	temp2 = (double)(i1) / 255;
 
@@ -826,7 +838,9 @@ printf("\nwp_r_end = %f, wp_g_end = %f, wp_b_end = %f\n", wp_r_end, wp_g_end, wp
     }
 
     // this is a replacement code for arrays for multi processing
+    #ifdef __OPENMP__
     #pragma omp parallel for num_threads(max_threads)
+    #endif
     for (i1=0; i1<256; i1++){
         for (i2=0; i2<max_threads; i2++){ hist2[i1] += hist2n[i1][i2]; } }
 
@@ -930,9 +944,13 @@ printf("\nwp_r_end = %f, wp_g_end = %f, wp_b_end = %f\n", wp_r_end, wp_g_end, wp
     gamma_weight_low_all = 0;
     gamma_weight_high_all = 0;
 
+    #ifdef __OPENMP__
     #pragma omp parallel for reduction(+:gamma_weight_low_all) num_threads(max_threads)
+    #endif
     for (i1=0;   i1<128; i1++){ gamma_weight_low_all  += hist2[i1]; }
+    #ifdef __OPENMP__
     #pragma omp parallel for reduction(+:gamma_weight_high_all) num_threads(max_threads)
+    #endif
     for (i1=128; i1<256; i1++){ gamma_weight_high_all += hist2[i1]; }
 
     // Hisztogramm súlypont megállapítása
@@ -997,7 +1015,9 @@ printf("\nwp_r_end = %f, wp_g_end = %f, wp_b_end = %f\n", wp_r_end, wp_g_end, wp
 // a 128 irányába
 
 
+    #ifdef __OPENMP__
     #pragma omp parallel for private(x, y, addr, addr2, col_r, col_g, col_b, col_r2, col_g2, col_b2, temp2, temp3, cc, H, S, L) num_threads(max_threads)
+    #endif
     for (y=0; y<=bh-1; y++){
         addr2 = y * bw * 3 + y * addr_offset;
         for (x=0; x<=bw-1; x++){
@@ -1135,7 +1155,9 @@ printf("\nwp_r_end = %f, wp_g_end = %f, wp_b_end = %f\n", wp_r_end, wp_g_end, wp
     }
 
     // this is a replacement code for arrays for multi processing
+    #ifdef __OPENMP__
     #pragma omp parallel for num_threads(max_threads)
+    #endif
     for (i1=0; i1<256; i1++){
         for (i2=0; i2<max_threads; i2++){ hist_satur[i1] += hist_saturn[i1][i2]; } }
 
@@ -1147,7 +1169,9 @@ printf("\nwp_r_end = %f, wp_g_end = %f, wp_b_end = %f\n", wp_r_end, wp_g_end, wp
     // Hisztogram átlag értékének megállapítása
     hist_satur_avg = 0;
 
+    #ifdef __OPENMP__
     #pragma omp parallel for reduction(+:hist_satur_avg) num_threads(max_threads)
+    #endif
     for (i1=255; i1>=0; i1--){
         hist_satur_avg += hist_satur[i1];
     }
@@ -1174,7 +1198,9 @@ printf("\nwp_r_end = %f, wp_g_end = %f, wp_b_end = %f\n", wp_r_end, wp_g_end, wp
     if (hist_satur_low > 0){ hist_satur_ok = satur_max / hist_satur_low; }
 
 
+    #ifdef __OPENMP__
     #pragma omp parallel for private(x, y, addr, addr2, col_r, col_g, col_b, col_r2, col_g2, col_b2, H, S, L, cc) num_threads(max_threads)
+    #endif
     for (y=0; y<=bh-1; y++){
         addr2 = y * bw * 3 + y * addr_offset;
         for (x=0; x<=bw-1; x++){
@@ -1228,7 +1254,9 @@ printf("\nwp_r_end = %f, wp_g_end = %f, wp_b_end = %f\n", wp_r_end, wp_g_end, wp
     }
 
     // this is a replacement code for arrays for multi processing
+    #ifdef __OPENMP__
     #pragma omp parallel for num_threads(max_threads)
+    #endif
     for (i1=0; i1<256; i1++){
         for (i2=0; i2<max_threads; i2++){ hist3[i1] += hist3n[i1][i2]; } }
 
